@@ -2,22 +2,22 @@ mod cache_control;
 mod export_sdl;
 mod stringify_exec_doc;
 
-use std::collections::{BTreeMap, BTreeSet, HashMap, HashSet};
-use std::fmt::{self, Display, Formatter};
-
-use indexmap::map::IndexMap;
-use indexmap::set::IndexSet;
-
-pub use crate::model::__DirectiveLocation;
-use crate::parser::types::{
-    BaseType as ParsedBaseType, Field, Type as ParsedType, VariableDefinition,
-};
-use crate::{
-    model, Any, Context, InputType, OutputType, Positioned, ServerResult, SubscriptionType, Value,
-    VisitorContext,
+use std::{
+    collections::{BTreeMap, BTreeSet, HashMap, HashSet},
+    fmt::{self, Display, Formatter},
 };
 
 pub use cache_control::CacheControl;
+pub use export_sdl::SDLExportOptions;
+use indexmap::{map::IndexMap, set::IndexSet};
+
+pub use crate::model::__DirectiveLocation;
+use crate::{
+    parser::types::{BaseType as ParsedBaseType, Field, Type as ParsedType, VariableDefinition},
+    schema::IntrospectionMode,
+    Any, Context, InputType, OutputType, Positioned, ServerResult, SubscriptionType, Value,
+    VisitorContext,
+};
 
 fn strip_brackets(type_name: &str) -> Option<&str> {
     type_name
@@ -32,8 +32,8 @@ pub enum MetaTypeName<'a> {
     Named(&'a str),
 }
 
-impl<'a> std::fmt::Display for MetaTypeName<'a> {
-    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+impl<'a> Display for MetaTypeName<'a> {
+    fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
         match self {
             MetaTypeName::Named(name) => write!(f, "{}", name),
             MetaTypeName::NonNull(name) => write!(f, "{}!", name),
@@ -167,7 +167,6 @@ pub struct MetaField {
     pub provides: Option<&'static str>,
     pub visible: Option<MetaVisibleFn>,
     pub compute_complexity: Option<ComplexityType>,
-    pub oneof: bool,
 }
 
 #[derive(Clone)]
@@ -387,7 +386,7 @@ impl MetaType {
 pub struct MetaDirective {
     pub name: &'static str,
     pub description: Option<&'static str>,
-    pub locations: Vec<model::__DirectiveLocation>,
+    pub locations: Vec<__DirectiveLocation>,
     pub args: IndexMap<String, MetaInputValue>,
     pub is_repeatable: bool,
     pub visible: Option<MetaVisibleFn>,
@@ -401,7 +400,7 @@ pub struct Registry {
     pub query_type: String,
     pub mutation_type: Option<String>,
     pub subscription_type: Option<String>,
-    pub disable_introspection: bool,
+    pub introspection_mode: IntrospectionMode,
     pub enable_federation: bool,
     pub federation_subscription: bool,
 }
@@ -481,7 +480,8 @@ impl Registry {
                 }
             }
             None => {
-                // Inserting a fake type before calling the function allows recursive types to exist.
+                // Inserting a fake type before calling the function allows recursive types to
+                // exist.
                 self.types.insert(
                     name.to_string(),
                     MetaType::Object {
@@ -632,7 +632,6 @@ impl Registry {
                         provides: None,
                         visible: None,
                         compute_complexity: None,
-                        oneof: false,
                     },
                 );
 
@@ -664,7 +663,6 @@ impl Registry {
                         provides: None,
                         visible: None,
                         compute_complexity: None,
-                        oneof: false,
                     },
                 );
             }
@@ -695,7 +693,6 @@ impl Registry {
                             provides: None,
                             visible: None,
                             compute_complexity: None,
-                            oneof: false,
                         },
                     );
                     fields
