@@ -119,78 +119,25 @@ async fn test_flatten_with_context() {
 }
 
 #[tokio::test]
-async fn test_oneof_field() {
-    #[derive(OneofObject)]
-    enum TestArg {
-        A(i32),
-        B(String),
-    }
-
+async fn test_object_process_with_field() {
     struct Query;
 
     #[Object]
     impl Query {
-        #[graphql(oneof)]
-        async fn test(&self, arg: TestArg) -> String {
-            match arg {
-                TestArg::A(a) => format!("a:{}", a),
-                TestArg::B(b) => format!("b:{}", b),
-            }
+        async fn test(
+            &self,
+            #[graphql(process_with = "str::make_ascii_uppercase")] processed_arg: String,
+        ) -> String {
+            processed_arg
         }
     }
 
     let schema = Schema::new(Query, EmptyMutation, EmptySubscription);
-    let query = "{ test(a: 10) }";
+    let query = "{ test(processedArg: \"smol\") }";
     assert_eq!(
         schema.execute(query).await.into_result().unwrap().data,
         value!({
-            "test": "a:10"
-        })
-    );
-
-    let query = r#"{ test(b: "abc") }"#;
-    assert_eq!(
-        schema.execute(query).await.into_result().unwrap().data,
-        value!({
-            "test": "b:abc"
-        })
-    );
-
-    let query = r#"{
-        __type(name: "Query") {
-            fields {
-                name
-                args {
-                    name
-                    type {
-                        kind
-                        name
-                    }
-                }
-            }
-        }
-    }"#;
-    assert_eq!(
-        schema.execute(query).await.into_result().unwrap().data,
-        value!({
-            "__type": {
-                "fields": [{
-                    "name": "test",
-                    "args": [{
-                        "name": "a",
-                        "type": {
-                            "kind": "SCALAR",
-                            "name": "Int"
-                        }
-                    }, {
-                        "name": "b",
-                        "type": {
-                            "kind": "SCALAR",
-                            "name": "String"
-                        }
-                    }]
-                }]
-            }
+            "test": "SMOL"
         })
     );
 }
